#!/bin/csh -f
#
# exifmod.csh MRH 26-Oct-06 / 17-Jan-07
#
# Writes metadata in image files. 
# All EXIF and IPTC data for title, author, and keywords can be replaced.
# Always run as cmd line script, not as droplet

# ============================================================
# Setup constants and defaults
# ============================================================
#set echo

set prog_name = exifmod.csh

set exiftool = "/Applications/Image-ExifTool/exiftool";
if (`hostname` == "xray.bmc.uu.se") set exiftool = "/home/markh/exiftooldir/exiftool";

set year = `date +"%Y"`;

set city = "Uppsala, Sweden";

set app = "";

# ============================================================
# process params
# ============================================================

set filein = "";
set title = "";
set author = "";
set keywords = "";
set location = "";
set bundle = "0";

# Give help if no params given
if ($#argv == 0) goto help 

# Check prm count and types
set iopt = 0;
if ($#argv < 1) then
    echo "No parameters to $prog_name";
    goto help
endif

# Loop through args
set iopt = 0;
argloop:
    @ iopt++;
    if ($iopt> $#argv) goto lastarg;

    if ("$argv[$iopt]" == "help" || "$argv[$iopt]" == "-h" || "$argv[$iopt]" == "-help" || "$argv[$iopt]" == "--" || $#argv == 0) then 
help:
        echo "Usage : $prog_name -filein filename [-title title] [-author author] [-keywords keywords] [-location location] [-append] [-overwrite] [-bundle bundledir] [-quiet] [-help] [-fullhelp] [filename] [directory]";
        exit 0

    else if ("$argv[$iopt]" == "-quiet") then
        set exiftool = "$exiftool -q";

    else if ("$argv[$iopt]" == "-silent") then
        set exiftool = "$exiftool -q";

    else if ("$argv[$iopt]" == "-overwrite") then
        set exiftool = "$exiftool -overwrite_original_in_place -P";

    else if ("$argv[$iopt]" == "-filein") then
        @ iopt++;
	set filein = \""$argv[$iopt]"\"

    else if ("$argv[$iopt]" == "-title") then
        @ iopt++;
        set title = "$argv[$iopt]";

    else if ("$argv[$iopt]" == "-location") then
        @ iopt++;
        set location = "$argv[$iopt]";

    else if ("$argv[$iopt]" == "-city") then
        @ iopt++;
        set city = "$argv[$iopt]";

    else if ("$argv[$iopt]" == "-author") then
        @ iopt++;
        set author = "$argv[$iopt]";

    else if ("$argv[$iopt]" == "-keywords") then
        @ iopt++;
        set keywords = "$argv[$iopt]";

    else if ("$argv[$iopt]" == "-append") then
        set app = "+";

    else if ("$argv[$iopt]" == "-bundle") then
        @ iopt++;
	# This must be first prm so that exiftool starts right
	set city = "";
        set bundle = "$argv[$iopt]";
	set exiftool = "$bundle/Contents/Resources/Image-ExifTool-stripped/exiftool";

    else if ("$argv[$iopt]" == "-fullhelp") then
        echo "$prog_name modifies exif data in image file";
        exit 0
    else
	set filein = "$filein "\""$argv[$iopt]"\"
        #echo "Unrecognised option : " "$argv[$iopt]";
    endif

    goto argloop
lastarg:

if ("$filein" == "") then
    echo "Error - No filename given";
    goto help
endif

# ============================================================
# Process each option
# ============================================================

if ("$keywords" != "") then

    set keywords_prm = "";
    set keywords = `echo "$keywords" | sed -e s/","/,\ /`
    set keywords = `echo $keywords | sed -e s/",\([^\ ]\)"/,\ \\1/g` # Check comma has space

    set k = ($keywords);
    set nk = $#k;
    set extra = "";
    set i = 0

    foreach k ($keywords) # Step through keywords
      @ i++

      if (`echo $k | grep ","` == "" && $i != $nk) then # Concat commaless words (except last)
        set extra = "$extra$k "
        continue
      endif

      set k = `echo $k | sed -e s/","//` # Remove the commas and make separate flags
      set exiftool = "$exiftool -keywords${app}="\""$extra$k"\";
      set extra = "";
    end

endif

if ("$author" != "") then
    if ("$author" == "markh") set author = "Mark Harris";
    if ("$author" == "mikaelnilsson") set author = "Mikael Nilsson";
    if ("$author" == "daniele") set author = "Daniel Eriksson";
    if ("$author" == "dereko") set author = "Derek Ogg";
    set exiftool = "$exiftool -author="\""$author"\";
    set exiftool = "$exiftool -creator="\""$author"\";
    set exiftool = "$exiftool -artist="\""$author"\";
    set exiftool = "$exiftool -rights="\""$author"\";
    set exiftool = "$exiftool -by-line="\""$author"\";
    set exiftool = "$exiftool -copyright="\""C $year $author"\";
    set exiftool = "$exiftool -copyrightnotice="\""C $year $author"\";
    #set exiftool = "$exiftool -copyrightflag="\""1"\";
endif

if ("$title" != "") then
    set exiftool = "$exiftool -title="\""$title"\";
    set exiftool = "$exiftool -description="\""$title"\";
    set exiftool = "$exiftool -objectname="\""$title"\";
    set exiftool = "$exiftool -imagedescription="\""$title"\";
    set exiftool = "$exiftool -caption-abstract="\""$title"\";
endif

if ("$city" != "") then
    set exiftool = "$exiftool -creatorcontactinfociadrcity="\""$city"\";
endif

if ("$location" != "") then
    set exiftool = "$exiftool -location="\""$location"\";
endif

set exiftool = "$exiftool $filein"; # Append the filename

#echo $exiftool

# And do the insertion
# ====================

eval $exiftool

exit
